Authors
=======

.. hint::
   Want to be a part of the project? Read how to `contribute and join us <https://neurokit2.readthedocs.io/en/latest/contributing/index.html>`_!


Core team
----------------

* `Dominique Makowski <https://github.com/DominiqueMakowski>`_ *(Nanyang Technological University, Singapore)*
* `Tam Pham <https://github.com/Tam-Pham>`_ *(Nanyang Technological University, Singapore)*
* `Zen Juen Lau <https://github.com/zen-juen>`_ *(Nanyang Technological University, Singapore)*
* `Jan C. Brammer <https://github.com/JanCBrammer>`_ *(Radboud University, Netherlands)*
* `François Lespinasse <https://github.com/sangfrois>`_ *(Université de Montréal, Canada)*


Contributors
-------------

* `Hung Pham <https://github.com/hungpham2511>`_ *(Eureka Robotics, Singapore)*
* `Christopher Schölzel <https://github.com/CSchoel>`_ *(THM University of Applied Sciences, Germany)*
* `Duy Le <https://github.com/duylp>`_ *(Hubble, Singapore)*
* `Stavros Avramidis <https://github.com/purpl3F0x>`_
* `Tiago Rodrigues <https://github.com/TiagoTostas>`_ *(IST, Lisbon)*
* `Mitchell Bishop <https://github.com/Mitchellb16>`_ *(NINDS, USA)*
* `Robert Richer <https://github.com/richrobe>`_ *(FAU Erlangen-Nürnberg, Germany)*
* `Russell Anderson <https://github.com/rpanderson>`_ *(La Trobe Institute for Molecular Science, Australia)*
* `Alexander Wong <https://github.com/awwong1>`_ *(University of Alberta, Canada)*
* `Elaine Teo <https://github.com/elaineteo2000>`_ *(University College London)*
* `Raimon Padrós <https://github.com/raimonpv>`_ *(Universitat politècnica de Catalunya, Spain - Massachusetts General Hospital, USA)*
* `Minsoo Yeo <https://github.com/minsooyeo>`_ *(Taewoong Medical Co., Ltd., ROK)*
* `Celal Savur <https://github.com/csavur>`_ *(Rochester Institute of Technology, USA)*
* `Jacob Epifano <https://github.com/jrepifano>`_ *(Rowan University - Children's Hospital of Philadelphia, USA)*


Thanks also to `Gansheng Tan <https://github.com/GanshengT>`_, `Chuan-Peng Hu <https://github.com/hcp4715>`_, `@ucohen <https://github.com/ucohen>`_, `Anthony Gatti <https://github.com/gattia>`_, `Julien Lamour <https://github.com/lamourj>`_, `@renatosc <https://github.com/renatosc>`_, `Nicolas Beaudoin-Gagnon <https://github.com/Fegalf>`_ and `@rubinovitz <https://github.com/rubinovitz>`_ for their contribution in `NeuroKit 1 <https://github.com/neuropsychology/NeuroKit.py>`_.

How to Cite
-------------


Makowski, D., Pham, T., Lau, Z. J., Brammer, J. C., Lespinasse, F., Pham, H.,
Schölzel, C., & Chen, S. A. (2021). NeuroKit2: A Python toolbox for neurophysiological signal processing.
Behavior Research Methods. https://doi.org/10.3758/s13428-020-01516-y


Full bibtex reference:

.. code-block:: tex

    @article{Makowski2021neurokit,
      author = {Makowski, Dominique and Pham, Tam and Lau, Zen J. and Brammer, Jan C. and Lespinasse, Fran{\c{c}}ois and Pham, Hung and Sch{\"o}lzel, Christopher and Chen, S. H. Annabel},
      title={NeuroKit2: A Python toolbox for neurophysiological signal processing},
      journal={Behavior Research Methods},
      year={2021},
      month={Feb},
      day={02},
      abstract={NeuroKit2 is an open-source, community-driven, and user-centered Python package for neurophysiological signal processing. It provides a comprehensive suite of processing routines for a variety of bodily signals (e.g., ECG, PPG, EDA, EMG, RSP). These processing routines include high-level functions that enable data processing in a few lines of code using validated pipelines, which we illustrate in two examples covering the most typical scenarios, such as an event-related paradigm and an interval-related analysis. The package also includes tools for specific processing steps such as rate extraction and filtering methods, offering a trade-off between high-level convenience and fine-tuned control. Its goal is to improve transparency and reproducibility in neurophysiological research, as well as foster exploration and innovation. Its design philosophy is centred on user-experience and accessibility to both novice and advanced users.},
      issn={1554-3528},
      doi={10.3758/s13428-020-01516-y},
      url={https://doi.org/10.3758/s13428-020-01516-y}
    }
..